#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <unistd.h>

#include "libvodisp.h"

int vodisp_load_bitmap24(const char *path, char *buf)
{
	FILE *fp = fopen(path, "rb");

	if (fp == NULL)
		return 0;

	// skip first 54 bit if it is bitmap file.
	if (strstr(path, ".bmp"))
		fseek(fp, 54, SEEK_SET);
	fread(buf, 1, FRAMESIZE, fp);
	fclose(fp);

	return FRAMESIZE;
}

int vodisp_load_bitmap16(const char *path, char *buf)
{
	FILE *fp = fopen(path, "rb");

	if (fp == NULL)
		return 0;

	// skip first 54 bit if it is bitmap file.
	if (strstr(path, ".bmp"))
		fseek(fp, 138, SEEK_SET);
	fread(buf, 1, FRAMESIZE16, fp);
	fclose(fp);

	return FRAMESIZE16;
}

void vodisp_test()
{
	char frame[FRAMESIZE];
	int i;

	while (1) {
		bzero(frame, FRAMESIZE);	// red
		for (i = 0; i < FRAMESIZE; i += 3)
			frame[i + 2] = 0xff;
		vodisp_write_frame(frame);
		sleep(1);

		bzero(frame, FRAMESIZE);	// green
		for (i = 0; i < FRAMESIZE; i += 3)
			frame[i + 1] = 0xff;
		vodisp_write_frame(frame);
		sleep(1);

		bzero(frame, FRAMESIZE);	// blue
		for (i = 0; i < FRAMESIZE; i += 3)
			frame[i    ] = 0xff;
		vodisp_write_frame(frame);
		sleep(1);

		for (i = 0; i < 256; i += 64) {	// gray scale.
			memset(frame, i, FRAMESIZE);
			vodisp_write_frame(frame);
			sleep(1);
		}
	}
}



int main(int argc, char *argv[])
{
	char buf[FRAMESIZE];
	int code;

	if (argc == 1) {
		printf("usage: vodisp [type vocore2|djn1522|touch0x] [dimmer 0-100|bmp16 path|bmp24 path|test]\n");
		return 0;
	}
	if (code = vodisp_connect(argv[1]), code < 0) {
		printf("failed to connect to screen, code %d.\n", code);
		return -1;
	}
	if (argc == 2)
		return 0;

	if (strcmp(argv[2], "dimmer") == 0) {
		int dimmer = atoi(argv[3]);
		code = vodisp_control(VODISP_DIMMER, &dimmer);
	} else if (strcmp(argv[2], "bmp16") == 0) {
		int param = VODISP_PIXFMT_16BIT;
		vodisp_control(VODISP_PIXFMT, &param);
		if (argc == 4) {
			vodisp_load_bitmap16(argv[3], buf);
			vodisp_write_frame(buf);
		}
	} else if (strcmp(argv[2], "bmp24") == 0) {
		int param = VODISP_PIXFMT_24BIT;
		vodisp_control(VODISP_PIXFMT, &param);
		if (argc == 4) {
			vodisp_load_bitmap24(argv[3], buf);
			vodisp_write_frame(buf);
		}
	} else if (strcmp(argv[2], "test") == 0) {
		int param = VODISP_PIXFMT_24BIT;
		vodisp_control(VODISP_PIXFMT, &param);
		vodisp_test();
	}
	return 0;
}
